==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Modify/Explode/ts/Explode_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Diálogo
Abre diálogo de cores</translatorcomment>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Arcos e círculos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em segmentos de linha (comprimento fixo)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em segmentos de linha (ângulo fixo)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translatorcomment>--exact match--
--file: pt.po--
Desenha Elipses
Exibe o menu &quot;Elipse&quot;</translatorcomment>
        <translation>Elipses</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em polyline com segmentos de arco</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em polyline com segmentos de linha</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Desenhe chavetas (NURBS)
Desenha chavetas</translatorcomment>
        <translation>Chaveta</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Exibe o menu &quot;Dimensão&quot;
&amp;Dimensões</translatorcomment>
        <translation>Cotas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em linhas, sólidos e textos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translatorcomment>--google--
Desenhe hachurados e preenchimentos sólidos
Hachuras / preenchimentos sólidos
&amp;Combine Hachuras</translatorcomment>
        <translation>Escotilhas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em linhas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translatorcomment>--exact match--
--file: BlockExamples_pt.ts--
Fragmente carimbos e outros agrupamentos de entidades
Oculte (congele) todos os carimbos</translatorcomment>
        <translation>Blocos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em entidades</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Fragmente
&amp;Fragmente Texto em Letras</translatorcomment>
        <translation>&amp;Explodir</translation>
    </message>
    <message>
        <location filename="../Explode.js" line="+31"/>
        <source>Modify</source>
        <translation>Modifique</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Fragmente</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Spline segments:</source>
        <translation>Segmentos de spline:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Segmentos de elipse:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Modify/Explode/ts/Explode_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Diálogo
Abre diálogo de cores</translatorcomment>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Arcos e Círculos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em segmentos de linha (comprimento fixo)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em segmentos de linha (ângulo fixo)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translatorcomment>--exact match--
--file: pt.po--
Desenha Elipses
Exibe o menu &quot;Elipse&quot;</translatorcomment>
        <translation>Elipses</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em polyline com segmentos de arco</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em polyline com segmentos de linha</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Desenhe chavetas (NURBS)
Desenha chavetas</translatorcomment>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Exibe o menu &quot;Dimensão&quot;
&amp;Dimensões</translatorcomment>
        <translation>Dimensões</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>em linhas, sólidos e textos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translatorcomment>--google--
Desenhe hachurados e preenchimentos sólidos
Hachuras / preenchimentos sólidos
&amp;Combine Hachuras</translatorcomment>
        <translation>Hachuras</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>para linhas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translatorcomment>--exact match--
--file: BlockExamples_pt.ts--
Fragmente carimbos e outros agrupamentos de entidades
Oculte (congele) todos os carimbos</translatorcomment>
        <translation>Blocos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>para entidades</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Fragmente
&amp;Fragmente Texto em Letras</translatorcomment>
        <translation>&amp;Fragmente</translation>
    </message>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modifique</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Fragmente</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Spline segments:</source>
        <translation>Segmentos de spline:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Segmentos de elipse (por elipse inteira):</translation>
    </message>
</context>
</TS>
